@@ -342,8 +342,6 @@ class Dialcentral(object):
 			self._notebookTapHandler.on_holding = self._set_tab_refresh
 			self._notebookTapHandler.on_cancel = self._reset_tab_refresh
 
-			self._initDone = True
-
 			config = ConfigParser.SafeConfigParser()
 			config.read(constants._user_settings_)
 			with gtk_toolbox.gtk_lock():
@@ -352,6 +350,7 @@ class Dialcentral(object):
 			with gtk_toolbox.gtk_lock():
 				self._errorDisplay.push_exception()
 		finally:
+			self._initDone = True
 			self._spawn_attempt_login()
 
 	def _spawn_attempt_login(self, *args):
@@ -388,6 +387,10 @@ class Dialcentral(object):
 					hildonize.show_information_banner(self._window, "Logged In")
 				else:
 					hildonize.show_information_banner(self._window, "Login Failed")
+				if not self._phoneBackends[self._defaultBackendId].get_callback_number():
+					# subtle reminder to the users to configure things
+					self._notebook.set_current_page(self.ACCOUNT_TAB)
+
 		except Exception, e:
 			with gtk_toolbox.gtk_lock():
 				self._errorDisplay.push_exception()
@@ -411,15 +414,30 @@ class Dialcentral(object):
 		"""
 		@note Thread agnostic
 		"""
-		loggedIn = self._phoneBackends[self._defaultBackendId].is_authed()
+		loggedIn = False
+		if self._credentials == ("", ""):
+			# Disallow logging in by cookie alone, without credentials
+			loggedIn = False
+
+		if not loggedIn:
+			loggedIn = self._phoneBackends[self._defaultBackendId].is_authed()
+
 		if loggedIn:
 			_moduleLogger.info("Logged into %r through cookies" % self._phoneBackends[self._defaultBackendId])
+		else:
+			# If the cookies are bad, scratch them completely
+			self._phoneBackends[self._defaultBackendId].logout()
+
 		return loggedIn
 
 	def _login_by_settings(self):
 		"""
 		@note Thread agnostic
 		"""
+		if self._credentials == ("", ""):
+			# Don't bother with the settings if they are blank
+			return False
+
 		username, password = self._credentials
 		loggedIn = self._phoneBackends[self._defaultBackendId].login(username, password)
 		if loggedIn:
@@ -438,10 +456,6 @@ class Dialcentral(object):
 				credentials = self._credentialsDialog.request_credentials(
 					defaultCredentials = self._credentials
 				)
-				if not self._phoneBackends[tmpServiceId].get_callback_number():
-					# subtle reminder to the users to configure things
-					self._notebook.set_current_page(self.ACCOUNT_TAB)
-
 				banner = hildonize.show_busy_banner_start(self._window, "Logging In...")
 			try:
 				username, password = credentials
@@ -487,9 +501,6 @@ class Dialcentral(object):
 		self._messagesViews[newStatus].enable()
 		self._contactsViews[newStatus].enable()
 
-		if self._phoneBackends[self._selectedBackendId].get_callback_number() is None:
-			self._phoneBackends[self._selectedBackendId].set_sane_callback()
-
 		self._selectedBackendId = newStatus
 
 		self._accountViews[self._selectedBackendId].update()
